@@ -11,6 +11,7 @@ from tensorlake.documentai.models import (
     Figure,
     MimeType,
     ModelProvider,
+    OcrPipelineProvider,
     Options,
     Page,
     PageClass,
@@ -21,6 +22,7 @@ from tensorlake.documentai.models import (
     ParseStatus,
     ParsingOptions,
     PartitionStrategy,
+    Region,
     Signature,
     StructuredData,
     StructuredExtractionOptions,
@@ -33,10 +35,12 @@ from tensorlake.documentai.models import (
 
 __all__ = [
     "DocumentAI",
+    "Region",
     # Enums
     "ChunkingStrategy",
     "MimeType",
     "ModelProvider",
+    "OcrPipelineProvider",
     "ParseStatus",
     "PartitionStrategy",
     "TableOutputMode",
