@@ -9,11 +9,14 @@ from ._enums import (
     ChunkingStrategy,
     MimeType,
     ModelProvider,
+    OcrPipelineProvider,
     ParseStatus,
     PartitionStrategy,
+    Region,
     TableOutputMode,
     TableParsingFormat,
 )
+from ._errors import DocumentAIError, ErrorCode, ErrorResponse
 from ._filters import DatasetDataFilter
 
 # Options
@@ -47,6 +50,7 @@ __all__ = [
     "ChunkingStrategy",
     "MimeType",
     "ModelProvider",
+    "OcrPipelineProvider",
     "ParseStatus",
     "PartitionStrategy",
     "TableOutputMode",
@@ -78,4 +82,9 @@ __all__ = [
     "PaginationDirection",
     # Filters
     "DatasetDataFilter",
+    "Region",
+    # Errors
+    "ErrorCode",
+    "ErrorResponse",
+    "DocumentAIError",
 ]
