@@ -103,6 +103,7 @@ _DEFAULT_CPU: float = 1.0
 _DEFAULT_MEMORY_GB: float = 1.0
 _DEFAULT_EPHEMERAL_DISK_GB: float = 2.0  # 2 GB
 _DEFAULT_GPU = None  # No GPU by default
+_DEFAULT_MAX_CONCURRENCY = 1  # No concurrent threads running the function by default
 
 
 class TensorlakeCompute:
@@ -115,9 +116,13 @@ class TensorlakeCompute:
         gpu (Optional[str]): GPU(s) available to the function. No GPU is allocated by default.
                              The value should be a string "GPU_MODEL:COUNT" representing the GPU model and the number of GPUs.
                              See supported GPU models and counts in Tensorlake Cloud documentation.
+        region (Optional[str]): The region where this function should be executed (e.g., "us-west", "eu-central").
+                                If specified, the function will only run on executors in that region;
+                                otherwise, the function may run anywhere globally.
         cacheable (bool): Declares that applications of this function are cacheable.
                           A function should only be marked cacheable if its outputs are a
                           pure function of its inputs.
+        max_concurrency (int): The maximum number of concurrent executions of this function. 1 by default, max value is 100.
     """
 
     name: str = ""
@@ -134,8 +139,10 @@ class TensorlakeCompute:
     memory: float = _DEFAULT_MEMORY_GB
     ephemeral_disk: float = _DEFAULT_EPHEMERAL_DISK_GB
     gpu: Optional[Union[str, List[str]]] = _DEFAULT_GPU
+    region: Optional[str] = None
     next: Optional[Union["TensorlakeCompute", List["TensorlakeCompute"]]] = None
     cacheable: bool = False
+    max_concurrency: int = _DEFAULT_MAX_CONCURRENCY
 
     def run(self, *args, **kwargs) -> Union[List[Any], Any]:
         pass
@@ -203,8 +210,10 @@ def tensorlake_function(
     memory: float = _DEFAULT_MEMORY_GB,
     ephemeral_disk: float = _DEFAULT_EPHEMERAL_DISK_GB,
     gpu: Optional[Union[str, List[str]]] = _DEFAULT_GPU,
+    region: Optional[str] = None,
     next: Optional[Union["TensorlakeCompute", List["TensorlakeCompute"]]] = None,
     cacheable: bool = False,
+    max_concurrency: int = _DEFAULT_MAX_CONCURRENCY,
 ):
     def construct(fn):
         attrs = {
@@ -227,9 +236,11 @@ def tensorlake_function(
             "memory": memory,
             "ephemeral_disk": ephemeral_disk,
             "gpu": gpu,
+            "region": region,
             "cacheable": cacheable,
             "run": staticmethod(fn),
             "next": next,
+            "max_concurrency": max_concurrency,
         }
 
         return type("TensorlakeCompute", (TensorlakeCompute,), attrs)
